<?php

namespace Drupal\support_mail\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

class MailForm extends FormBase {

  /**
   * Gets the configuration names that will be editable.
   *
   * @return array
   *   An array of configuration object names that are editable if called in
   *   conjunction with the trait's config() method.
   */
  protected function getEditableConfigNames() {
    return [];
  }

  /**
   * Returns a unique string identifying the form.
   *
   * @return string
   *   The unique string identifying the form.
   */
  public function getFormId() {
    return 'support_mail_sendmail';
  }

  /**
   * Form constructor.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array
   *   The form structure.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

  $form['support_mail_to'] = array(
    '#title'         => t('Recipient'),
    '#type'          => 'textfield',
    '#description'   => t('The recipient address of the email.'),
  );
  $form['support_mail_subject'] = array(
    '#title'         => t('Subject'),
    '#type'          => 'textfield',
    '#description'   => t('The subject of the email.'),
  );
  $form['support_mail_message'] = array(
    '#title'         => t('Message'),
    '#type'          => 'textarea',
    '#description'   => t('The body of the email.'),
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => 'Send email',
  );
  return $form;
  }

/**
  * {@inheritdoc}
  */
  public function validateForm(array &$form, FormStateInterface $form_state)
  {
      if (!\Drupal::service('email.validator')->isValid($form_state->getValue('support_mail_to'))) {
        $form_state->setErrorByName('support_mail_to', $this->t('Enter a valid email address.'));
      }
      if ($form_state->getValue('support_mail_subject') == '') {
        $form_state->setErrorByName('support_mail_subject', $this->t('Enter the subject of the email.'));
      }
      if ($form_state->getValue('support_mail_message') == '') {
        $form_state->setErrorByName('support_mail_message', $this->t('Enter the body of the email.'));
      }
  }

  /**
   * Form submission handler for station import.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

  $params = array(
    'subject' => strip_tags($form_state->getValue('support_mail_subject')),
    'body' => strip_tags($form_state->getValue('support_mail_message')),
  );
  $langcode = \Drupal::currentUser()->getPreferredLangcode();
  $mailManager = \Drupal::service('plugin.manager.mail');
  $result = $mailManager->mail("support_mail", "support_mail", $form_state->getValue('support_mail_to'), $langcode, $params, NULL, TRUE);
  if($result['result'] !== TRUE){
    drupal_set_message('There was a problem sending your email and it was not send', 'error');
  }else{
    drupal_set_message('Your message has been send');
  }
  }


}
